==> streaming-stt-nemo-0.0.4a4.tar.gz: streaming-stt-nemo-0.0.4a4/streaming_stt_nemo/configs.py <==
# NEON AI (TM) SOFTWARE, Software Development Kit & Application Framework
# All trademark and other rights reserved by their respective owners
# Copyright 2008-2022 Neongecko.com Inc.
# Contributors: Daniel McKnight, Guy Daniels, Elon Gasper, Richard Leeds,
# Regina Bloomstine, Casimiro Ferreira, Andrii Pernatii, Kirill Hrymailo
# BSD-3 License
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# 1. Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
# 3. Neither the name of the copyright holder nor the names of its
#    contributors may be used to endorse or promote products derived from this
#    software without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS  BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
# OR PROFITS;  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE,  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


languages = {
    "en": {
        "model": "stt_en_citrinet_512_gamma_0_25", 
    },
    "es": {
        "model": "neongeckocom/stt_es_citrinet_512_gamma_0_25", 
    },
    "fr": {
        "model": "stt_fr_citrinet_1024_gamma_0_25", 
    },
    "de": {
        "model": "neongeckocom/stt_de_citrinet_512_gamma_0_25", 
    },
    "it": {
        "model": "neongeckocom/stt_it_citrinet_512_gamma_0_25", 
    },
    "uk": {
        "model": "neongeckocom/stt_uk_citrinet_512_gamma_0_25", 
    },
    "ca": {
        "model": "neongeckocom/stt_ca_citrinet_512_gamma_0_25", 
    },
}

==> streaming-stt-nemo-0.1.1a0.tar.gz: streaming-stt-nemo-0.1.1a0/streaming_stt_nemo/configs.py <==
# NEON AI (TM) SOFTWARE, Software Development Kit & Application Framework
# All trademark and other rights reserved by their respective owners
# Copyright 2008-2022 Neongecko.com Inc.
# Contributors: Daniel McKnight, Guy Daniels, Elon Gasper, Richard Leeds,
# Regina Bloomstine, Casimiro Ferreira, Andrii Pernatii, Kirill Hrymailo
# BSD-3 License
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# 1. Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
# 3. Neither the name of the copyright holder nor the names of its
#    contributors may be used to endorse or promote products derived from this
#    software without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS  BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
# OR PROFITS;  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE,  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


languages = {
    "en": {
        "model": "neongeckocom/stt_en_citrinet_512_gamma_0_25", 
    },
    "es": {
        "model": "neongeckocom/stt_es_citrinet_512_gamma_0_25", 
    },
    "fr": {
        "model": "stt_fr_citrinet_1024_gamma_0_25", 
    },
    "de": {
        "model": "neongeckocom/stt_de_citrinet_512_gamma_0_25", 
    },
    "it": {
        "model": "neongeckocom/stt_it_citrinet_512_gamma_0_25", 
    },
    "uk": {
        "model": "neongeckocom/stt_uk_citrinet_512_gamma_0_25", 
    },
    "nl": {
        "model": "neongeckocom/stt_nl_citrinet_512_gamma_0_25", 
    },
    "pt": {
        "model": "neongeckocom/stt_pt_citrinet_512_gamma_0_25", 
    },
    "ca": {
        "model": "neongeckocom/stt_ca_citrinet_512_gamma_0_25", 
    },
}
